package com.huiju.estateagents.property.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.collect.Maps;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.taUser.entity.TaUser;
import com.huiju.estateagents.center.taUser.mapper.TaUserMapper;
import com.huiju.estateagents.center.taUser.service.ITaUserService;
import com.huiju.estateagents.property.common.Constant;
import com.huiju.estateagents.property.common.UserElement;
import com.huiju.estateagents.property.dao.*;
import com.huiju.estateagents.property.model.*;
import com.huiju.estateagents.property.service.SocialServiceI;
import com.huiju.estateagents.property.vo.TpTicketVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author weichaochao
 * @Title: SocialServiceImpl
 * @date 2018/10/23
 */
@Service("SocialService")
@Transactional
public class SocialServiceImpl implements SocialServiceI {

    @Autowired
    private TpAnnouncementMapper tpAnnouncementMapper;

    @Autowired
    private TpSocialViewMapper tpSocialViewMapper;

    @Autowired
    private TdImagesMapper tdImagesMapper;

    @Override
    @Transactional
    public TpAnnouncement findAnnouncementDetail(Integer id, Integer orgId, Integer userId) {
        //更新此用户的查看次数操作
        Integer allViewNum = updateSocialView(userId, Constant.ANNOUNCEMENT, orgId, id);
        if (null != allViewNum) {
            tpAnnouncementMapper.updateByPrimaryKeySelective(id, allViewNum);
        }
        TpAnnouncement tpAnnouncement = tpAnnouncementMapper.selectByPrimaryKey(id, orgId);
//        tpAnnouncement.setUserName(tpUserMapper.selectByPrimaryKey(tpAnnouncement.getCreateUser()).getUserName());
//        tpAnnouncement.setUserName(tpUserMapper.selectByPrimaryKey(tpAnnouncement.getCreateUser()).getUserName());

        Map<String, Object> map = Maps.newHashMap();
        map.put("uuid", tpAnnouncement.getId());
        map.put("type", Constant.ANNOUNCEMENT);
        // 查询图片
        List<TdImages> tdImagesList = tdImagesMapper.getByUUIDAndByType(map);
        List<String> imgList = tdImagesList.stream().map(e -> new String(e.getImageUrl())).collect(Collectors.toList());
        tpAnnouncement.setImgList(imgList);
        return tpAnnouncement;
    }

    /**
     * 分页获取公告列表
     *
     * @param orgId
     * @param title
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseBean getAnnouncements(Integer orgId, String title, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        Map<String, Object> parameter = Maps.newHashMap();
        //使用分页插件
        Page<TpAnnouncement> page = new Page<>(pageNum, pageSize);
        // 获取数据
        IPage<TpAnnouncement> wxAnnouncementsPage = tpAnnouncementMapper.getWxAnnouncements(page, orgId, title);
        responseBean.addSuccess(wxAnnouncementsPage);
        return responseBean;
    }



    /**
     * 更新此用户的查看次数操作
     *
     * @param userId
     * @param socialType
     * @param orgId
     * @param uuid
     */
    private Integer updateSocialView(Integer userId, String socialType, Integer orgId, Integer uuid) {
        //检查是否查看过这个帖子
        TpSocialView tpSocialView = new TpSocialView();
        tpSocialView.setTaUserId(userId);
        tpSocialView.setSocialType(socialType);
        tpSocialView.setOrgId(orgId);
        tpSocialView.setUuid(uuid);
        Integer viewNum = tpSocialViewMapper.selectViewNum(tpSocialView);

        //查看过的话查看次数加一
        if (viewNum == 0) {
            tpSocialView.setCreateDate(new Date());
            tpSocialViewMapper.insertSelective(tpSocialView);
            tpSocialView.setTaUserId(null);
            Integer allViewNum = tpSocialViewMapper.selectViewNum(tpSocialView);
            return allViewNum;
        }
        return null;
    }
}